Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2941)

Unified Diff: chrome/browser/ui/browser.h

Issue 2688413012: Don't animate the download shelf when entering/exiting fullscreen. (Closed)
Patch Set: Turn on animation for all tests except the one that was flaky due to animation. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/download/test_download_shelf.cc ('k') | chrome/browser/ui/browser.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/browser.h
diff --git a/chrome/browser/ui/browser.h b/chrome/browser/ui/browser.h
index c741ab75d058398551c47b905edd79cf017a2327..59da0950995703000b7478c54ec6e1acb1660bc1 100644
--- a/chrome/browser/ui/browser.h
+++ b/chrome/browser/ui/browser.h
@@ -368,9 +368,10 @@ class Browser : public TabStripModelObserver,
// External state change handling ////////////////////////////////////////////
- // Invoked when the fullscreen state of the window changes.
- // BrowserWindow::EnterFullscreen invokes this after the window has become
- // fullscreen.
+ // BrowserWindow::EnterFullscreen invokes WindowFullscreenStateWillChange at
+ // the beginning of a fullscreen transition, and WindowFullscreenStateChanged
+ // at the end.
+ void WindowFullscreenStateWillChange();
void WindowFullscreenStateChanged();
// Assorted browser commands ////////////////////////////////////////////////
« no previous file with comments | « chrome/browser/download/test_download_shelf.cc ('k') | chrome/browser/ui/browser.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698